mod anchor;
mod color;
mod event;
mod rect;
mod state;
mod vector;

pub use anchor::*;
pub use color::*;
pub use event::*;
pub use rect::*;
pub use state::*;
pub use vector::*;

use rhai::{exported_module, Engine};

pub fn register_into_engine(engine: &mut Engine) {
	engine
		// Helpers
		.build_type::<Rect>()
		.build_type::<Color>()
		.build_type::<UiVector>()
		// State
		.build_type::<State>()
		.build_type::<ShipState>()
		.build_type::<SystemObjectState>()
		// Events
		.build_type::<MouseClickEvent>()
		.build_type::<MouseHoverEvent>()
		.build_type::<PlayerShipStateEvent>()
		// Bigger modules
		.register_type_with_name::<Anchor>("Anchor")
		.register_static_module("Anchor", exported_module!(anchor_mod).into());
}
